# PiReplay

Capture a video and instantly replay the last moments from your phone or computer.

PiReplay is a device that allows you to instantly record and replay the past 5 to 60 seconds of real-life events directly from your phone or computer.
This has unlimited applications but is primarly useful when analyzing a key moment in sports, reviewing gameplay, or simply reliving funny moments.
You simply press a button and instantly get a video of the last few seconds that just happened - live replay, IRL.

Python Package `pireplay` CLI (managed using [Poetry](https://python-poetry.org/)).

**Note**: please take a look at the project's GitHub repository **<https://github.com/gruvw/pireplay>**.

## Installation

- Install by running: `sudo pip install pireplay --break-system-packages`
- CLI Usage: `pireplay --help`

**Note**: this program is only intended to run on a RaspberryPi using a camera module (for the PiReplay software).
